@@ -40,6 +40,10 @@ type eventSpinnerUpdate struct {
 
 type eventMoreLinesAvailable struct{}
 
+// Either reading, highlighting or both are done. Check reader.Done() and
+// reader.HighlightingDone() for details.
+type eventMaybeDone struct{}
+
 // Styling of line numbers
 var _numberStyle = twin.StyleDefault.WithAttr(twin.AttrDim)
 
@@ -70,6 +74,9 @@ type Pager struct {
 
 	WrapLongLines bool
 
+	// Ref: https://github.com/walles/moar/issues/113
+	QuitIfOneScreen bool
+
 	// Ref: https://github.com/walles/moar/issues/94
 	ScrollLeftHint  twin.Cell
 	ScrollRightHint twin.Cell
@@ -207,6 +214,7 @@ func (p *Pager) Quit() {
 	p.preHelpState = nil
 }
 
+// Negative deltas move left instead
 func (p *Pager) moveRight(delta int) {
 	if p.ShowLineNumbers && delta > 0 {
 		p.ShowLineNumbers = false
@@ -411,17 +419,17 @@ func (p *Pager) onRune(char rune) {
 
 // StartPaging brings up the pager on screen
 func (p *Pager) StartPaging(screen twin.Screen) {
+	log.Trace("Pager starting")
+	defer log.Trace("Pager done")
+
 	unprintableStyle = p.UnprintableStyle
 	ConsumeLessTermcapEnvs()
 
 	p.screen = screen
 
 	go func() {
-		for {
-			// Wait for new lines to appear...
-			<-p.reader.moreLinesAdded
-
-			// ... and notify the main loop so it can show them:
+		for range p.reader.moreLinesAdded {
+			// Notify the main loop about the new lines so it can show them
 			screen.Events() <- eventMoreLinesAvailable{}
 
 			// Delay updates a bit so that we don't waste time refreshing
@@ -436,19 +444,10 @@ func (p *Pager) StartPaging(screen twin.Screen) {
 
 	go func() {
 		// Spin the spinner as long as contents is still loading
-		done := false
 		spinnerFrames := [...]string{"/.\\", "-o-", "\\O/", "| |"}
 		spinnerIndex := 0
 		for {
-			// Break this loop on the reader.done signal...
-			select {
-			case <-p.reader.done:
-				done = true
-			default:
-				// This default case makes this an async read
-			}
-
-			if done {
+			if p.reader.done.Load() {
 				break
 			}
 
@@ -465,12 +464,37 @@ func (p *Pager) StartPaging(screen twin.Screen) {
 		screen.Events() <- eventSpinnerUpdate{""}
 	}()
 
+	go func() {
+		for range p.reader.maybeDone {
+			screen.Events() <- eventMaybeDone{}
+		}
+	}()
+
 	// Main loop
 	spinner := ""
 	for !p.quit {
 		if len(screen.Events()) == 0 {
-			// Nothing more to process for now, redraw the screen!
-			p.redraw(spinner)
+			// Nothing more to process for now, redraw the screen
+			overflow := p.redraw(spinner)
+
+			// Ref:
+			// https://github.com/gwsw/less/blob/ff8869aa0485f7188d942723c9fb50afb1892e62/command.c#L828-L831
+			if p.QuitIfOneScreen && overflow == didFit && !p.isShowingHelp {
+				// Do the slow (atomic) checks only if the fast ones (no locking
+				// required) passed
+				if p.reader.done.Load() && p.reader.highlightingDone.Load() {
+					// Ref:
+					// https://github.com/walles/moar/issues/113#issuecomment-1368294132
+					p.ShowLineNumbers = false // Requires a redraw to take effect, see below
+					p.DeInit = false
+					p.quit = true
+
+					// Without this the line numbers setting ^ won't take effect
+					p.redraw(spinner)
+
+					break
+				}
+			}
 		}
 
 		event := <-screen.Events()
@@ -509,6 +533,10 @@ func (p *Pager) StartPaging(screen twin.Screen) {
 				p.scrollToEnd()
 			}
 
+		case eventMaybeDone:
+			// Do nothing. We got this just so that we'll do the QuitIfOneScreen
+			// check (above) as soon as highlighting is done.
+
 		case eventSpinnerUpdate:
 			spinner = event.spinner
 
@@ -528,7 +556,7 @@ func (p *Pager) StartPaging(screen twin.Screen) {
 func (p *Pager) ReprintAfterExit() error {
 	// Figure out how many screen lines are used by pager contents
 
-	renderedScreenLines, _ := p.renderScreenLines()
+	renderedScreenLines, _, _ := p.renderScreenLines()
 	screenLinesCount := len(renderedScreenLines)
 
 	_, screenHeight := p.screen.Size()
