@@ -252,6 +252,7 @@ func main() {
 		"colors", formatters.TTY256, "Highlighting palette size: 8, 16, 256, 16M, auto", parseColorsOption)
 	noLineNumbers := flagSet.Bool("no-linenumbers", false, "Hide line numbers on startup, press left arrow key to show")
 	noStatusBar := flagSet.Bool("no-statusbar", false, "Hide the status bar, toggle with '='")
+	quitIfOneScreen := flagSet.Bool("quit-if-one-screen", false, "Don't page if contents fits on one screen")
 	noClearOnExit := flagSet.Bool("no-clear-on-exit", false, "Retain screen contents when exiting moar")
 	statusBarStyle := flagSetFunc(flagSet, "statusbar", m.STATUSBAR_STYLE_INVERSE,
 		"Status bar style: inverse, plain or bold", parseStatusBarStyle)
@@ -301,7 +302,7 @@ func main() {
 	}
 
 	log.SetFormatter(&log.TextFormatter{
-		TimestampFormat: time.RFC3339Nano,
+		TimestampFormat: time.StampMicro,
 	})
 
 	if len(flagSet.Args()) > 1 {
@@ -363,6 +364,7 @@ func main() {
 		// Display input pipe contents
 		reader = m.NewReaderFromStream("", os.Stdin)
 	} else {
+		// Display the input file contents
 		reader, err = m.NewReaderFromFilename(*inputFilename, *style, *formatter)
 		if err != nil {
 			fmt.Fprintf(os.Stderr, "ERROR: %v\n", err)
@@ -370,13 +372,13 @@ func main() {
 		}
 	}
 
-	// Display the input file contents
 	pager := m.NewPager(reader)
 	pager.WrapLongLines = *wrap
 	pager.Following = *follow
 	pager.ShowLineNumbers = !*noLineNumbers
 	pager.ShowStatusBar = !*noStatusBar
 	pager.DeInit = !*noClearOnExit
+	pager.QuitIfOneScreen = *quitIfOneScreen
 	pager.StatusBarStyle = *statusBarStyle
 	pager.UnprintableStyle = *unprintableStyle
 	pager.ScrollLeftHint = *scrollLeftHint
